Event

Struct Event 

pub struct Event { /* private fields */ }
Events are a concrete implementation of the Eventable trait.

Implementations

Source

impl Event

pub fn data(&self) -> Option<&str>

Borrows the data for this event

pub fn data_mut(&mut self) -> Option<&mut Cow<'static, str>>

Mutably borrow the data for this event

pub fn set_data(&mut self, data: impl Into<Cow<'static, str>>) -> &mut Self

Sets the data for this event, returning &mut Self for chaining

pub fn with_data(self, data: impl Into<Cow<'static, str>>) -> Self

Owned chainable setter for the data for this event, returning Self

pub fn comment(&self) -> Option<&str>

Borrows a comment for this event

pub fn comment_mut(&mut self) -> Option<&mut Cow<'static, str>>

Mutably borrow a comment for this event

pub fn set_comment( &mut self, comment: impl Into<Cow<'static, str>>, ) -> &mut Self

Sets a comment for this event, returning &mut Self for chaining

pub fn with_comment(self, comment: impl Into<Cow<'static, str>>) -> Self

Owned chainable setter for a comment for this event, returning Self

pub fn event_type(&self) -> Option<&str>

Borrows the type for this event

pub fn type_mut(&mut self) -> Option<&mut Cow<'static, str>>

Mutably borrow the type for this event

pub fn set_type( &mut self, event_type: impl Into<Cow<'static, str>>, ) -> &mut Self

Sets the type for this event, returning &mut Self for chaining

pub fn with_type(self, event_type: impl Into<Cow<'static, str>>) -> Self

Owned chainable setter for the type for this event, returning Self

pub fn id(&self) -> Option<&str>

Borrows the id for this event

pub fn id_mut(&mut self) -> Option<&mut Cow<'static, str>>

Mutably borrow the id for this event

pub fn set_id(&mut self, id: impl Into<Cow<'static, str>>) -> &mut Self

Sets the id for this event, returning &mut Self for chaining

pub fn with_id(self, id: impl Into<Cow<'static, str>>) -> Self

Owned chainable setter for the id for this event, returning Self

pub fn retry(&self) -> Option<Duration>

Returns a copy of reconnection time for this stream

pub fn retry_mut(&mut self) -> Option<&mut Duration>

Mutably borrow reconnection time for this stream

pub fn set_retry(&mut self, retry: Duration) -> &mut Self

Sets reconnection time for this stream, returning &mut Self for chaining

pub fn with_retry(self, retry: Duration) -> Self

Owned chainable setter for reconnection time for this stream, returning Self

Source

impl Event

pub fn new(data: impl Into<Cow<'static, str>>) -> Self

builds a new Event

by default, this event has no event type. to set an event type, use Event::with_type or Event::set_type

pub fn new_comment(comment: impl Into<Cow<'static, str>>) -> Self

builds a new comment-only Event, with no data

Clients ignore comments and dispatch no event for this message. Sending one periodically keeps an otherwise idle event stream from being closed by intermediaries.

let event = trillium_sse::Event::new_comment("heartbeat");
assert_eq!(event.comment(), Some("heartbeat"));
assert_eq!(event.data(), None);